@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.635';
+our $VERSION = '1.636';
 
 use Exporter qw( import );
 
@@ -446,8 +446,8 @@ sub table_char_width { [
 [  0x3099,   0x309a, 0],
 [  0x309b,   0x30ff, 2],
 [  0x3100,   0x3104, 1],
-[  0x3105,   0x312e, 2],
-[  0x312f,   0x3130, 1],
+[  0x3105,   0x312f, 2],
+[  0x3130,   0x3130, 1],
 [  0x3131,   0x318e, 2],
 [  0x318f,   0x318f, 1],
 [  0x3190,   0x31ba, 2],
@@ -716,8 +716,8 @@ sub table_char_width { [
 [ 0x16f93,  0x16fdf, 1],
 [ 0x16fe0,  0x16fe1, 2],
 [ 0x16fe2,  0x16fff, 1],
-[ 0x17000,  0x187ec, 2],
-[ 0x187ed,  0x187ff, 1],
+[ 0x17000,  0x187f1, 2],
+[ 0x187f2,  0x187ff, 1],
 [ 0x18800,  0x18af2, 2],
 [ 0x18af3,  0x1afff, 1],
 [ 0x1b000,  0x1b11e, 2],
@@ -826,20 +826,24 @@ sub table_char_width { [
 [ 0x1f6d3,  0x1f6ea, 1],
 [ 0x1f6eb,  0x1f6ec, 2],
 [ 0x1f6ed,  0x1f6f3, 1],
-[ 0x1f6f4,  0x1f6f8, 2],
-[ 0x1f6f9,  0x1f90f, 1],
+[ 0x1f6f4,  0x1f6f9, 2],
+[ 0x1f6fa,  0x1f90f, 1],
 [ 0x1f910,  0x1f93e, 2],
 [ 0x1f93f,  0x1f93f, 1],
-[ 0x1f940,  0x1f94c, 2],
-[ 0x1f94d,  0x1f94f, 1],
-[ 0x1f950,  0x1f96b, 2],
-[ 0x1f96c,  0x1f97f, 1],
-[ 0x1f980,  0x1f997, 2],
-[ 0x1f998,  0x1f9bf, 1],
-[ 0x1f9c0,  0x1f9c0, 2],
-[ 0x1f9c1,  0x1f9cf, 1],
-[ 0x1f9d0,  0x1f9e6, 2],
-[ 0x1f9e7,  0x1ffff, 1],
+[ 0x1f940,  0x1f970, 2],
+[ 0x1f971,  0x1f972, 1],
+[ 0x1f973,  0x1f976, 2],
+[ 0x1f977,  0x1f979, 1],
+[ 0x1f97a,  0x1f97a, 2],
+[ 0x1f97b,  0x1f97b, 1],
+[ 0x1f97c,  0x1f9a2, 2],
+[ 0x1f9a3,  0x1f9af, 1],
+[ 0x1f9b0,  0x1f9b9, 2],
+[ 0x1f9ba,  0x1f9bf, 1],
+[ 0x1f9c0,  0x1f9c2, 2],
+[ 0x1f9c3,  0x1f9cf, 1],
+[ 0x1f9d0,  0x1f9ff, 2],
+[ 0x1fa00,  0x1ffff, 1],
 [ 0x20000,  0x2fffd, 2],
 [ 0x2fffe,  0x2ffff, 1],
 [ 0x30000,  0x3fffd, 2],
